.. _metrics:
======================
Quantification Metrics
======================

.. automodule:: qp.metrics.metrics
    :members:
    :undoc-members:
    :no-index:

.. automodule:: qp.metrics.array_metrics
    :members:
    :undoc-members:
    :no-index:

.. automodule:: qp.metrics.brier
    :no-index:
.. autoclass:: Brier
    :members:
    :no-index:

.. automodule:: qp.metrics.pit
    :no-index:
.. autoclass:: PIT
    :members:
    :no-index: